summaryrefslogtreecommitdiffstats
path: root/models/pull.go
diff options
context:
space:
mode:
Diffstat (limited to 'models/pull.go')
-rw-r--r--models/pull.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/models/pull.go b/models/pull.go
index f1b92bff58..5157b61fef 100644
--- a/models/pull.go
+++ b/models/pull.go
@@ -339,7 +339,7 @@ func (pr *PullRequest) Merge(doer *User, baseGitRepo *git.Repository) (err error
return nil
}
// patchConflicts is a list of conflit description from Git.
var patchConflicts = []string{
"patch does not apply",
"already exists in working directory",
@@ -347,7 +347,7 @@ var patchConflicts = []string{
"error:",
}
// testPatch checks if patch can be merged to base repository without conflit.
// FIXME: make a mechanism to clean up stable local copies.
func (pr *PullRequest) testPatch() (err error) {
if pr.BaseRepo == nil {
@@ -384,7 +384,7 @@ func (pr *PullRequest) testPatch() (err error) {
if err != nil {
for i := range patchConflicts {
if strings.Contains(stderr, patchConflicts[i]) {
- log.Trace("PullRequest[%d].testPatch (apply): has conflit", pr.ID)
+ log.Trace("PullRequest[%d].testPatch (apply): has conflict", pr.ID)
fmt.Println(stderr)
pr.Status = PullRequestStatusConflict
return nil
@@ -339,7 +339,7 @@ func (pr *PullRequest) Merge(doer *User, baseGitRepo *git.Repository) (err error
return nil
}
-// patchConflicts is a list of conflit description from Git.
+// patchConflicts is a list of conflict description from Git.
var patchConflicts = []string{
"patch does not apply",
@@ -347,7 +347,7 @@ var patchConflicts = []string{
"error:",
}
-// testPatch checks if patch can be merged to base repository without conflit.
+// testPatch checks if patch can be merged to base repository without conflict.
// FIXME: make a mechanism to clean up stable local copies.
func (pr *PullRequest) testPatch() (err error) {